# Introduction

[Let's Encrypt](https://letsencrypt.org) is a Certificate Authority that
issues SSL certificates for free.
Validation is done by checking a file on the web server.
**Awesome!**

See the introduction video:
[Let's Encrypt - A Free Robotic Certificate Authority](https://www.youtube.com/watch?v=OZyXx8Ie4pA)

# Get Free Certificate

The [official client](https://github.com/letsencrypt/letsencrypt)
is fully automated. However, it uses root and installs packages.

This guide uses [acme-tiny](https://github.com/diafygi/acme-tiny), because:

* It does not attempt to modify server config files
* Works with any X.509 certificate
* Does not require root
* Small single-file Python script

Download:

	wget https://github.com/diafygi/acme-tiny/raw/master/acme_tiny.py

## 1. Create User Account

*Note: Only needed the first time.*

	openssl genrsa -out user.key 4096

## 2. Generate Domain Key

*Note: Only needed the first time, or when changing the key.*

	openssl genrsa -out domain.key 2048

## 3. Create Challenge/Response Directory

*Note: Only needed when requesting a certificate in Step 5.*

Create a directory which is readable by the web server
and writable by the user executing acme-tiny. This guide uses `/data/letsencrypt`.

For Nginx, the config snippet [`inc/letsencrypt`](../conf/nginx/inc/letsencrypt) can be included.
It may be necessary to disable `listen 80` in the vhost config file.

## 4. Generate Certificate Signing Request

`CMDSAN` lists all domains to include in the certificate.

	CMDSAN="DNS:www.example.com,DNS:otherhost.example.com"

	openssl req -new -key domain.key -out domain.csr -subj / \
	-reqexts CMDSAN -config <(cat /etc/ssl/openssl.cnf <(printf "[CMDSAN]\nsubjectAltName=$CMDSAN\n"))

## 5. Request Certificate

**Note: This step needs to be repeated every less than 90 days.**

	python acme_tiny.py --account-key user.key --csr domain.csr --acme-dir /data/letsencrypt > domain.crt
